@@ -237,7 +237,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[MATCH_RECORD] =
 		gtk_signal_new ("match_record",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, match_record),
 				gtk_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
@@ -245,7 +245,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[FREE_MATCH] =
 		gtk_signal_new ("free_match",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, free_match),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -253,7 +253,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[ARCHIVE_LOCAL] =
 		gtk_signal_new ("archive_local",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, archive_local),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -261,7 +261,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[ARCHIVE_REMOTE] =
 		gtk_signal_new ("archive_remote",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, archive_remote),
 				gtk_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
@@ -269,7 +269,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[STORE_REMOTE] =
 		gtk_signal_new ("store_remote",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, store_remote),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -277,7 +277,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[ITERATE] =
 		gtk_signal_new ("iterate",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, iterate),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
@@ -285,7 +285,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[ITERATE_SPECIFIC] =
 		gtk_signal_new ("iterate_specific",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, iterate_specific),
 				gtk_marshal_INT__POINTER_INT_INT,
 				GTK_TYPE_INT, 3, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_INT);
@@ -293,7 +293,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[PURGE] =
 		gtk_signal_new ("purge",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, purge),
 				gtk_marshal_INT__NONE,
 				GTK_TYPE_INT, 0);
@@ -301,7 +301,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[SET_STATUS] =
 		gtk_signal_new ("set_status",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, set_status),
 				gtk_marshal_INT__POINTER_INT,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
@@ -309,7 +309,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[SET_PILOT_ID] =
 		gtk_signal_new ("set_pilot_id",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, set_pilot_id),
 				gtk_marshal_INT__POINTER_INT,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
@@ -317,7 +317,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[COMPARE] =
 		gtk_signal_new ("compare",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, compare),
 				gtk_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
@@ -325,7 +325,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[COMPARE_BACKUP] =
 		gtk_signal_new ("compare_backup",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, compare_backup),
 				gtk_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
@@ -333,7 +333,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[FREE_TRANSMIT] =
 		gtk_signal_new ("free_transmit",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, free_transmit),
 				gtk_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
@@ -341,7 +341,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[DELETE_ALL] =
 		gtk_signal_new ("delete_all",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, delete_all),
 				gtk_marshal_INT__NONE,
 				GTK_TYPE_INT, 0);
@@ -349,7 +349,7 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[TRANSMIT] =
 		gtk_signal_new ("transmit",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, transmit),
 				gtk_marshal_INT__POINTER_POINTER,
 				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
@@ -357,13 +357,11 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	pilot_conduit_standard_abs_signals[PRE_SYNC] =
 		gtk_signal_new ("pre_sync",
 				GTK_RUN_LAST,
-				object_class->type,
+				GTK_CLASS_TYPE (object_class),
 				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, pre_sync),
 				gtk_marshal_INT__POINTER,
 				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
 
-	gtk_object_class_add_signals (object_class, pilot_conduit_standard_abs_signals, LAST_SIGNAL);
-
 	conduit_standard_class->copy_to_pilot = gnome_pilot_conduit_standard_real_copy_to_pilot;
 	conduit_standard_class->copy_from_pilot = gnome_pilot_conduit_standard_real_copy_from_pilot;
 	conduit_standard_class->merge_to_pilot = gnome_pilot_conduit_standard_real_merge_to_pilot;
