@@ -41,7 +41,7 @@ gint         gnome_pilot_conduit_sync_type_str_to_int(const gchar *s);
 const gchar* gnome_pilot_conduit_sync_type_int_to_str(GnomePilotConduitSyncType e);
 
 struct _GPilotSyncOpt {
-	GnomePilotConduitSyncType default_sync_action;
+	GnomePilotConduitSyncType default_sync_action; /* Unused, but exists for bin compat */
 	gchar *basedir;
 };
 typedef struct _GPilotSyncOpt GPilotSyncOpt;
