@@ -284,6 +284,13 @@ gpilotd_corba_pause(GNOME_Pilot_Daemon obj,
 	return;
 }
 
+static void
+gpilotd_corba_reread_config (GNOME_Pilot_Daemon obj,
+			     CORBA_Environment *ev)
+{
+	kill(getpid(),SIGHUP);
+}
+
 /********************************************************************************/
 
 static void
@@ -1344,6 +1351,7 @@ PortableServer_ServantBase__epv base_epv = {
 POA_GNOME_Pilot_Daemon__epv daemon_epv = { 
 	NULL, 
 	(gpointer)&gpilotd_corba_pause,
+	(gpointer)&gpilotd_corba_reread_config,
 	(gpointer)&gpilotd_corba_noop,
 	(gpointer)&gpilotd_corba_request_install,
 	(gpointer)&gpilotd_corba_request_restore,
